import { type Snippet } from 'svelte';
export interface AccordionContext {
    open: (id: string) => void;
    close: (id: string) => void;
    toggle: (id: string) => void;
    isOpen: (id: string) => boolean;
    animDuration: number;
    iconOpen?: Snippet;
    iconClosed?: Snippet;
}
export interface AccordionProps {
    /** Enables opening multiple items at once. */
    multiple?: boolean;
    /** Takes an array list of open items. */
    value?: string[];
    /** The slide animation duration in milliseconds. */
    animDuration?: number;
    /** Sets base styles. */
    base?: string;
    /** Set padding styles. */
    padding?: string;
    /** Set vertical spacing styles. */
    spaceY?: string;
    /** Set border radius styles. */
    rounded?: string;
    /** Set the width styles. */
    width?: string;
    /** Provide arbitrary CSS classes. */
    classes?: string;
    /** The default child slot. */
    children: Snippet;
    /** Set the open state icon. */
    iconOpen?: Snippet;
    /** Set the closed state icon. */
    iconClosed?: Snippet;
}
export interface AccordionItemProps {
    /** Set a unique ID for the item. */
    id: string;
    /** Set a disabled state for the item. */
    disabled?: boolean;
    /** Sets base styles. */
    base?: string;
    /** Set vertical spacing styles. */
    spaceY?: string;
    /** Provide arbitrary CSS classes. */
    classes?: string;
    /** Triggers on item open or close. */
    onclick?: (event: MouseEvent) => void;
    /** Sets control's base styles. */
    controlBase?: string;
    /** Sets control's the hover styles. */
    controlHover?: string;
    /** Sets control's the padding styles. */
    controlPadding?: string;
    /** Sets control's the border radius styles. */
    controlRounded?: string;
    /** Provide arbitrary CSS classes to the control. */
    controlClasses?: string;
    /** Set the base styles for the state icons. */
    iconsBase?: string;
    /** Set the panel's base styles. */
    panelBase?: string;
    /** Set the panel's padding styles. */
    panelPadding?: string;
    /** Set the panel's border-radius styles. */
    panelRounded?: string;
    /** Provide arbitrary CSS classes to the panel. */
    panelClasses?: string;
    /** The control's default slot. */
    control: Snippet;
    /** The control's lead icon slot. */
    controlLead?: Snippet;
    /** The panels's default slot. */
    panel?: Snippet;
}
